@@ -2,7 +2,7 @@ from django.apps import AppConfig
 
 
 class CouncilmaticConfig(AppConfig):
-    name = 'councilmatic_core'
+    name = "councilmatic_core"
     verbose_name = "Councilmatic"
 
     def ready(self):
