@@ -7,25 +7,28 @@ from django.db import models, migrations
 class Migration(migrations.Migration):
 
     dependencies = [
-        ('councilmatic_core', '0004_auto_20151214_1413'),
+        ("councilmatic_core", "0004_auto_20151214_1413"),
     ]
 
     operations = [
         migrations.AddField(
-            model_name='billdocument',
-            name='document_type',
-            field=models.CharField(max_length=255, choices=[(
-                'A', 'Attachment'), ('V', 'Version')], default='A'),
+            model_name="billdocument",
+            name="document_type",
+            field=models.CharField(
+                max_length=255,
+                choices=[("A", "Attachment"), ("V", "Version")],
+                default="A",
+            ),
             preserve_default=False,
         ),
         migrations.AddField(
-            model_name='document',
-            name='full_text',
+            model_name="document",
+            name="full_text",
             field=models.TextField(blank=True),
         ),
         migrations.AlterField(
-            model_name='document',
-            name='url',
+            model_name="document",
+            name="url",
             field=models.TextField(blank=True),
         ),
     ]
