@@ -7,13 +7,13 @@ from django.db import models, migrations
 class Migration(migrations.Migration):
 
     dependencies = [
-        ('councilmatic_core', '0007_auto_20151223_1150'),
+        ("councilmatic_core", "0007_auto_20151223_1150"),
     ]
 
     operations = [
         migrations.AddField(
-            model_name='bill',
-            name='ocr_full_text',
+            model_name="bill",
+            name="ocr_full_text",
             field=models.TextField(blank=True),
         ),
     ]
